# Changelog

<!--next-version-placeholder-->

## v1.0.3 (2022-05-31)
### Fix
* Update uri link ([`764ad41`](https://github.com/Stephen-RA-King/pynball/commit/764ad4117abbf5c3dc10d9f6cdc4eb37e8d9f59d))

## 1.0.2 (2022-05-31)

### First Release of 'pynball'



<!-- Markdown link & img dfn's -->

[github](https://github.com/Stephen-RA-King/pynball)
